<?php
/*
 * Plugin Name:       Woo Responsive Mobile Cart (EasyToolsWP)
 * Description:       A responsive cart widget that shows total price and updates automatically on mobile devices.
 * Version:           1.0.1
 * Requires at least: 6.6
 * Author:            EasyToolsWP.com
 * Requires Plugins:  woocommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

// Enqueue necessary scripts and styles
function etwp_enqueue_scripts() {
    wp_enqueue_style( 'etwp-styles', plugins_url( 'easytoolswp-responsive-cart.css', __FILE__ ) );
    wp_enqueue_script( 'etwp-scripts', plugins_url( 'easytoolswp-responsive-cart.js', __FILE__ ), array('jquery'), null, true );

    // Localize script to pass AJAX URL
    wp_localize_script( 'etwp-scripts', 'etwp_ajax_obj', array(
        'ajax_url' => admin_url( 'admin-ajax.php' )
    ));
}
add_action( 'wp_enqueue_scripts', 'etwp_enqueue_scripts' );

// AJAX handler for updating cart
function etwp_update_cart() {
    ob_start();
    woocommerce_mini_cart();
    $mini_cart = ob_get_clean();
    $data = array(
        'cart_html' => $mini_cart,
        'cart_total' => WC()->cart->get_cart_total()
    );
    wp_send_json( $data );
}
add_action( 'wp_ajax_nopriv_etwp_update_cart', 'etwp_update_cart' );
add_action( 'wp_ajax_etwp_update_cart', 'etwp_update_cart' );

// Add the widget to the footer
function etwp_add_cart_widget() {
    ?>
    <div id="etwp-cart-widget" class="etwp-cart-widget">
        <div id="etwp-cart-content">
            <?php woocommerce_mini_cart(); ?>
        </div>
        <div id="etwp-cart-total">
            <?php echo WC()->cart->get_cart_total(); ?>
        </div>
        <div id="etwp-cart-buttons">
            <a href="<?php echo wc_get_checkout_url(); ?>" class="button checkout"><?php _e( 'Gå til kassen', 'etwp' ); ?></a>
        </div>
    </div>
    <?php
}
add_action( 'wp_footer', 'etwp_add_cart_widget' );

// Ensure WooCommerce is active
function etwp_check_woocommerce() {
    if ( ! class_exists( 'WooCommerce' ) ) {
        add_action( 'admin_notices', function() {
            ?>
            <div class="error">
                <p><?php _e( 'EasytoolsWP Responsive Cart requires WooCommerce to be installed and active.', 'etwp' ); ?></p>
            </div>
            <?php
        });
        return false;
    }
    return true;
}
add_action( 'plugins_loaded', 'etwp_check_woocommerce' );
?>
